@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,12 +31,11 @@
 #ifndef __CORE_NA_IABOUT_H__
 #define __CORE_NA_IABOUT_H__
 
-/**
- * SECTION: na_iabout
- * @short_description: NAIAbout interface definition.
+/* @title NAIAbout
+ * @short_description: The #NAIAbout Interface Definition
  * @include: runtime/na-iabout.h
  *
- * This interface displays the 'About Nautilus Actions' dialog box.
+ * This interface displays the 'About Nautilus-Actions' dialog box.
  * The application name may be provided by the implementor ; else,
  * the name of the application will be displayed.
  */
@@ -45,19 +44,21 @@
 
 G_BEGIN_DECLS
 
-#define NA_IABOUT_TYPE						( na_iabout_get_type())
-#define NA_IABOUT( object )					( G_TYPE_CHECK_INSTANCE_CAST( object, NA_IABOUT_TYPE, NAIAbout ))
-#define NA_IS_IABOUT( object )				( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_IABOUT_TYPE ))
-#define NA_IABOUT_GET_INTERFACE( instance )	( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_IABOUT_TYPE, NAIAboutInterface ))
+#define NA_IABOUT_TYPE                        ( na_iabout_get_type())
+#define NA_IABOUT( object )                   ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_IABOUT_TYPE, NAIAbout ))
+#define NA_IS_IABOUT( object )                ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_IABOUT_TYPE ))
+#define NA_IABOUT_GET_INTERFACE( instance )   ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_IABOUT_TYPE, NAIAboutInterface ))
 
-typedef struct NAIAbout                 NAIAbout;
+typedef struct _NAIAbout                 NAIAbout;
 
-typedef struct NAIAboutInterfacePrivate NAIAboutInterfacePrivate;
+typedef struct _NAIAboutInterfacePrivate NAIAboutInterfacePrivate;
 
 typedef struct {
+	/*< private >*/
 	GTypeInterface            parent;
 	NAIAboutInterfacePrivate *private;
 
+	/*< public >*/
 	/**
 	 * get_application_name:
 	 * @iabout: this #NAIAbout implementor.
