@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -44,13 +44,13 @@
 
 /* private class data
  */
-struct NAIOProviderClassPrivate {
+struct _NAIOProviderClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAIOProviderPrivate {
+struct _NAIOProviderPrivate {
 	gboolean       dispose_has_run;
 	gchar         *id;
 	gchar         *name;
@@ -295,7 +295,7 @@ instance_finalize( GObject *object )
 	}
 }
 
-/**
+/*
  * na_io_provider_terminate:
  *
  * Called by on #NAPivot dispose(), free here resources allocated to
@@ -309,7 +309,7 @@ na_io_provider_terminate( void )
 	st_io_providers = NULL;
 }
 
-/**
+/*
  * na_io_provider_get_providers_list:
  * @pivot: the current #NAPivot instance.
  *
@@ -330,7 +330,14 @@ na_io_provider_get_providers_list( const NAPivot *pivot )
 
 		order = na_iprefs_read_string_list( NA_IPREFS( pivot ), IO_PROVIDER_KEY_ORDER, NULL );
 
-		g_debug( "%s: dumping providers order", thisfn );
+		if( g_slist_length( order ) > 0 ){
+			g_debug( "%s: dumping providers order", thisfn );
+
+		} else {
+			g_debug( "%s: initializing empty list with default I/O provider", thisfn );
+			order = g_slist_append( order, g_strdup( NA_DEFAULT_IO_PROVIDER ));
+		}
+
 		na_core_utils_slist_dump( thisfn, order );
 
 		setup_io_providers( pivot, order );
@@ -495,7 +502,7 @@ add_io_providers_from_prefs( const NAPivot *pivot, GList *runtime_providers )
 	return( providers );
 }
 
-/**
+/*
  * na_io_provider_reorder_providers_list:
  * @pivot: the #NAPivot instance of the application.
  *
@@ -525,7 +532,7 @@ na_io_provider_reorder_providers_list( const NAPivot *pivot )
 	na_core_utils_slist_free( order );
 }
 
-/**
+/*
  * na_io_provider_dump_providers_list:
  * @providers: the list of #NAIOProvider to be dumped.
  *
@@ -555,7 +562,7 @@ dump( const NAIOProvider *provider )
 	g_debug( "%s: item_changed_handler=%lu", thisfn, provider->private->item_changed_handler );
 }
 
-/**
+/*
  * na_io_provider_find_provider_by_id:
  * @providers: the current list of #NAIOProvider.
  * @id: the searched internal id.
@@ -584,9 +591,9 @@ na_io_provider_find_provider_by_id( GList *providers, const gchar *id )
 	return( provider );
 }
 
-/**
+/*
  * na_io_provider_get_writable_provider:
- * @iprefs: an implementor of the #NAIPrefs interface.
+ * @pivot: the #NAPivot instance.
  *
  * Returns: the first willing and able to write I/O provider, or NULL.
  *
@@ -617,10 +624,10 @@ na_io_provider_get_writable_provider( const NAPivot *pivot )
 	return( provider );
 }
 
-/**
+/*
  * na_io_provider_read_items:
  * @pivot: the #NAPivot object which owns the list of registered I/O
- * storage providers.
+ *  storage providers.
  * @messages: error messages.
  *
  * Loads the tree from I/O storage subsystems.
@@ -658,7 +665,7 @@ na_io_provider_read_items( const NAPivot *pivot, GSList **messages )
 
 	if( merged || !level_zero || !g_slist_length( level_zero )){
 		g_debug( "%s: rewriting level-zero", thisfn );
-		if( !na_pivot_write_level_zero( pivot, hierarchy )){
+		if( !na_pivot_write_level_zero( pivot, hierarchy, messages )){
 			g_warning( "%s: unable to update level-zero", thisfn );
 		}
 	}
@@ -893,7 +900,7 @@ filter_unwanted_items_rec( GList *hierarchy, gboolean load_disabled, gboolean lo
 	return( filtered );
 }
 
-/**
+/*
  * na_io_provider_get_id:
  * @provider: this #NAIOProvider.
  *
@@ -916,7 +923,7 @@ na_io_provider_get_id( const NAIOProvider *provider )
 	return( id );
 }
 
-/**
+/*
  * na_io_provider_get_name:
  * @provider: this #NAIOProvider.
  *
@@ -944,7 +951,7 @@ na_io_provider_get_name( const NAIOProvider *provider )
 	return( name );
 }
 
-/**
+/*
  * na_io_provider_is_user_readable_at_startup:
  * @provider: this #NAIOProvider.
  * @iprefs: an implementor of the #NAIPrefs interface.
@@ -987,7 +994,7 @@ na_io_provider_is_user_readable_at_startup( const NAIOProvider *provider, const
 	return( to_be_read );
 }
 
-/**
+/*
  * na_io_provider_is_user_writable:
  * @provider: this #NAIOProvider.
  * @iprefs: an implementor of the #NAIPrefs interface.
@@ -1026,7 +1033,7 @@ na_io_provider_is_user_writable( const NAIOProvider *provider, const NAIPrefs *i
 	return( writable );
 }
 
-/**
+/*
  * na_io_provider_is_locked_by_admin:
  * @provider: this #NAIOProvider.
  * @iprefs: an implementor of the #NAIPrefs interface.
@@ -1058,7 +1065,7 @@ na_io_provider_is_locked_by_admin( const NAIOProvider *provider, const NAIPrefs
 	return( locked );
 }
 
-/**
+/*
  * na_io_provider_get_provider:
  * @provider: the #NAIOProvider object.
  *
@@ -1083,7 +1090,7 @@ na_io_provider_get_provider( const NAIOProvider *provider )
 	return( instance );
 }
 
-/**
+/*
  * na_io_provider_is_willing_to_write:
  * @provider: this #NAIOProvider.
  *
@@ -1113,7 +1120,7 @@ na_io_provider_is_willing_to_write( const NAIOProvider *provider )
 	return( willing_to );
 }
 
-/**
+/*
  * na_io_provider_is_able_to_write:
  * @provider: this #NAIOProvider.
  *
@@ -1143,7 +1150,7 @@ na_io_provider_is_able_to_write( const NAIOProvider *provider )
 	return( able_to );
 }
 
-/**
+/*
  * na_io_provider_has_write_api:
  * @provider: this #NAIOProvider.
  *
@@ -1172,7 +1179,7 @@ na_io_provider_has_write_api( const NAIOProvider *provider )
 	return( has_api );
 }
 
-/**
+/*
  * na_io_provider_write_item:
  * @provider: this #NAIOProvider object.
  * @item: a #NAObjectItem to be written to the storage subsystem.
@@ -1209,7 +1216,7 @@ na_io_provider_write_item( const NAIOProvider *provider, const NAObjectItem *ite
 	return( ret );
 }
 
-/**
+/*
  * na_io_provider_delete_item:
  * @provider: this #NAIOProvider object.
  * @item: the #NAObjectItem item to be deleted.
@@ -1241,7 +1248,7 @@ na_io_provider_delete_item( const NAIOProvider *provider, const NAObjectItem *it
 	return( ret );
 }
 
-/**
+/*
  * na_io_provider_duplicate_data:
  * @provider: this #NAIOProvider object.
  * @dest: the target #NAObjectItem item.
@@ -1283,7 +1290,7 @@ na_io_provider_duplicate_data( const NAIOProvider *provider, NAObjectItem *dest,
 	return( ret );
 }
 
-/**
+/*
  * na_io_provider_get_readonly_tooltip:
  * @reason: the reason for why an item is not writable.
  *
@@ -1340,7 +1347,7 @@ na_io_provider_get_readonly_tooltip( guint reason )
 	return( tooltip );
 }
 
-/**
+/*
  * na_io_provider_get_return_code_label:
  * @code: the return code of an operation.
  *
