@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -522,13 +522,13 @@ instance_dispose( GObject *window )
 			g_debug( "%s: quitting assistant", thisfn );
 			gtk_main_quit();
 			if( is_toplevel_initialized( self, self->private->toplevel_window )){
-				gtk_widget_hide_all( GTK_WIDGET( self->private->toplevel_window ));
+				gtk_widget_hide( GTK_WIDGET( self->private->toplevel_window ));
 			}
 
 		} else {
 			g_debug( "%s: quitting dialog", thisfn );
 			if( is_toplevel_initialized( self, self->private->toplevel_window )){
-				gtk_widget_hide_all( GTK_WIDGET( self->private->toplevel_window ));
+				gtk_widget_hide( GTK_WIDGET( self->private->toplevel_window ));
 			}
 		}
 
