@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -34,6 +34,8 @@
 
 #include <glib/gi18n.h>
 
+#include <api/na-core-utils.h>
+
 #include <core/na-io-provider.h>
 
 #include "nact-application.h"
@@ -42,9 +44,14 @@
 #include "nact-main-tab.h"
 #include "nact-main-menubar-file.h"
 
-static guint st_event_autosave = 0;
+static guint  st_event_autosave   = 0;
 
-static void     save_item( NactMainWindow *window, NAUpdater *updater, NAObjectItem *item );
+static gchar *st_save_error       = N_( "Save error" );
+static gchar *st_save_warning     = N_( "Some items may not have been saved" );
+static gchar *st_level_zero_write = N_( "Unable to rewrite the level-zero items list" );
+static gchar *st_delete_error     = N_( "Some items cannot have been deleted" );
+
+static gboolean save_item( NactMainWindow *window, NAUpdater *updater, NAObjectItem *item, GSList **messages );
 static gboolean autosave_callback( NactMainWindow *window );
 static void     autosave_destroyed( NactMainWindow *window );
 
@@ -227,7 +234,7 @@ nact_main_menubar_file_on_new_profile( GtkAction *gtk_action, NactMainWindow *wi
  * Saving is not only saving modified items, but also saving hierarchy
  * (and order if alpha order is not set).
  *
- * This is the same function that #nact_main_menubar_file_save_items(), just with
+ * This is the same function that nact_main_menubar_file_save_items(), just with
  * different arguments.
  */
 void
@@ -248,8 +255,29 @@ nact_main_menubar_file_on_save( GtkAction *gtk_action, NactMainWindow *window )
  * @window: the #NactMainWindow main window.
  *
  * Save items.
- * This is the same function that #nact_main_menubar_file_on_save(), just with
- * different arguments.
+ * This is the same function that nact_main_menubar_file_on_save(), just
+ * with different arguments.
+ *
+ * Synopsis:
+ * - rewrite the level-zero items list
+ * - delete the items which are marked to be deleted
+ * - rewrite (i.e. delete/write) updated items
+ *
+ * The difficulty here is that some sort of pseudo-transactionnal process
+ * must be setup:
+ *
+ * - if the level-zero items list cannot be updated, then an error message
+ *   is displayed, and we abort the whole processus
+ *
+ * - if some items cannot be actually deleted, then an error message is
+ *   displayed, and the whole processus is aborted;
+ *   plus:
+ *   a/ items which have not been deleted must be restored (maybe marked
+ *      as deleted ?) -> so these items are modified
+ *   b/ the level-zero list must be updated with these restored items
+ *      and reset modified
+ *
+ * - idem if some items cannot be actually rewritten...
  */
 void
 nact_main_menubar_file_save_items( NactMainWindow *window )
@@ -262,37 +290,62 @@ nact_main_menubar_file_save_items( NactMainWindow *window )
 	gchar *label;
 	GList *new_pivot;
 	NAObjectItem *duplicate;
+	GSList *messages;
+	gchar *msg;
 
 	g_return_if_fail( NACT_IS_MAIN_WINDOW( window ));
 
 	g_debug( "%s: window=%p", thisfn, ( void * ) window );
 
-	/* get ride of notification messages of IOProviders
+	/* get ride of notification messages of I/O providers
 	 */
 	na_ipivot_consumer_allow_notify( NA_IPIVOT_CONSUMER( window ), FALSE, 0 );
 
-	/* remove deleted items
-	 * so that new actions with same id do not risk to be deleted later
-	 */
-	nact_main_window_remove_deleted( window );
-
-	/* always write the level zero list of items
+	/* always write the level zero list of items as the first save phase
 	 * and reset the corresponding modification flag
 	 */
 	application = NACT_APPLICATION( base_window_get_application( BASE_WINDOW( window )));
 	updater = nact_application_get_updater( application );
 	items = nact_iactions_list_bis_get_items( NACT_IACTIONS_LIST( window ));
+	messages = NULL;
+
+	if( !na_pivot_write_level_zero( NA_PIVOT( updater ), items, &messages )){
+		if( g_slist_length( messages )){
+			msg = na_core_utils_slist_join_at_end( messages, "\n" );
+		} else {
+			msg = g_strdup( st_level_zero_write );
+		}
+		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_ERROR, st_save_error, msg );
+		g_free( msg );
+		na_core_utils_slist_free( messages );
+		return;
+	}
 
-	na_pivot_write_level_zero( NA_PIVOT( updater ), items );
 	mis = ( MenubarIndicatorsStruct * ) g_object_get_data( G_OBJECT( window ), MENUBAR_PROP_INDICATORS );
 	mis->level_zero_order_changed = FALSE;
 
+	/* remove deleted items
+	 * so that new actions with same id do not risk to be deleted later
+	 */
+	if( !nact_main_window_remove_deleted( window, &messages )){
+		if( g_slist_length( messages )){
+			msg = na_core_utils_slist_join_at_end( messages, "\n" );
+		} else {
+			msg = g_strdup( st_delete_error );
+		}
+		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_ERROR, st_save_error, msg );
+		g_free( msg );
+		na_core_utils_slist_free( messages );
+		return;
+	}
+
 	/* recursively save the modified items
-	 * check is useless here if item was not modified, but not very costly
+	 * check is useless here if item was not modified, but not very costly;
 	 * above all, it is less costly to check the status here, than to check
 	 * recursively each and every modified item
 	 */
 	new_pivot = NULL;
+	messages = NULL;
 
 	for( it = items ; it ; it = it->next ){
 		label = na_object_get_label( it->data );
@@ -303,7 +356,7 @@ nact_main_menubar_file_save_items( NactMainWindow *window )
 				na_object_is_modified( it->data ) ? "True":"False" );
 		g_free( label );
 
-		save_item( window, updater, NA_OBJECT_ITEM( it->data ));
+		save_item( window, updater, NA_OBJECT_ITEM( it->data ), &messages );
 
 		duplicate = NA_OBJECT_ITEM( na_object_duplicate( it->data ));
 		na_object_reset_origin( it->data, duplicate );
@@ -311,6 +364,13 @@ nact_main_menubar_file_save_items( NactMainWindow *window )
 		new_pivot = g_list_prepend( new_pivot, duplicate );
 	}
 
+	if( g_slist_length( messages )){
+		msg = na_core_utils_slist_join_at_end( messages, "\n" );
+		base_window_error_dlg( BASE_WINDOW( window ), GTK_MESSAGE_WARNING, st_save_warning, msg );
+		g_free( msg );
+		na_core_utils_slist_free( messages );
+	}
+
 	na_pivot_set_new_items( NA_PIVOT( updater ), g_list_reverse( new_pivot ));
 	g_list_free( items );
 
@@ -335,7 +395,7 @@ nact_main_menubar_file_save_items( NactMainWindow *window )
  * level zero order has already been saved from tree store order, so that
  * we actually do not care of the exact order of level zero NAPivot items
  *
- * saving means non-recursively save modified NAObjectItem, simultaneously
+ * saving means recursively save modified NAObjectItem, simultaneously
  * reproducing the new item in NAPivot
  *  +- A
  *  |  +- B
@@ -348,21 +408,27 @@ nact_main_menubar_file_save_items( NactMainWindow *window )
  *  |  +- ...
  *  save order: A-B-C-D-E-F-G-H (first parent, then children)
  */
-static void
-save_item( NactMainWindow *window, NAUpdater *updater, NAObjectItem *item )
+static gboolean
+save_item( NactMainWindow *window, NAUpdater *updater, NAObjectItem *item, GSList **messages )
 {
+	gboolean ret;
 	NAIOProvider *provider_before;
 	NAIOProvider *provider_after;
 	GList *subitems, *it;
+	gchar *msg;
 
-	g_return_if_fail( NACT_IS_MAIN_WINDOW( window ));
-	g_return_if_fail( NA_IS_UPDATER( updater ));
-	g_return_if_fail( NA_IS_OBJECT_ITEM( item ));
+	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( window ), FALSE );
+	g_return_val_if_fail( NA_IS_UPDATER( updater ), FALSE );
+	g_return_val_if_fail( NA_IS_OBJECT_ITEM( item ), FALSE );
 
+	ret = TRUE;
 	provider_before = na_object_get_provider( item );
 
-	if( na_object_is_modified( item ) &&
-		nact_window_save_item( NACT_WINDOW( window ), item )){
+	if( na_object_is_modified( item )){
+		ret = FALSE;
+		msg = NULL;
+
+		if( nact_window_save_item( NACT_WINDOW( window ), item, &msg )){
 
 			if( NA_IS_OBJECT_ACTION( item )){
 				na_object_reset_last_allocated( item );
@@ -374,14 +440,22 @@ save_item( NactMainWindow *window, NAUpdater *updater, NAObjectItem *item )
 			if( provider_after != provider_before ){
 				g_signal_emit_by_name( window, TAB_UPDATABLE_SIGNAL_PROVIDER_CHANGED, item );
 			}
+
+		} else {
+			/* TODO:
+			 * add the error message to the GSList
+			 */
+		}
 	}
 
 	if( NA_IS_OBJECT_MENU( item )){
 		subitems = na_object_get_items( item );
 		for( it = subitems ; it ; it = it->next ){
-			save_item( window, updater, NA_OBJECT_ITEM( it->data ));
+			ret &= save_item( window, updater, NA_OBJECT_ITEM( it->data ), messages );
 		}
 	}
+
+	return( ret );
 }
 
 /**
